==> smartgwt-12.1p.zip: com/smartgwt/logicalstructure/widgets/tree/TreeGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tree;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TreeGridLogicalStructure extends ListGridLogicalStructure {
    public String alwaysShowOpener;
    public String animateFolderEffect;
    public String animateFolderMaxRows;
    public String animateFolders;
    public String animateFolderSpeed;
    public String animateFolderTime;
    public String autoAssignTreeField;
    public String autoFetchTextMatchStyle;
    public String autoPreserveOpenState;
    public String canAcceptDroppedRecords;
    public String canDragRecordsOut;
    public String canDropOnLeaves;
    public String canReorderRecords;
    public String canReparentNodes;
    public String canSelectAll;
    public String cantDragIntoChildMessage;
    public String cantDragIntoSelfMessage;
    public String cantDragMultipleNodeOccurencesMessage;
    public String cascadeSelection;
    public String closedIconSuffix;
    public String connectorImage;
    public String createDefaultTreeField;
    public String customIconDropProperty;
    public String customIconOpenProperty;
    public String customIconProperty;
    public String customIconSelectedProperty;
    public String dataFetchMode;
    public Tree dataProperties;
    public DataSource dataSourceAsDataSource;
    public String dataSourceAsString;
    public String displayNodeType;
    public String dropIconSuffix;
    public String extraIconGap;
    public String folderIcon;
    public String folderIconPadding;
    public String iconPadding;
    public String iconPaddingProperty;
    public String iconSize;
    public String indentRecordComponents;
    public String indentSize;
    public String initialData;
    public String keepParentsOnFilter;
    public String leaveSelectionCheckboxGap;
    public String loadDataOnDemand;
    public String loadingIcon;
    public String manyItemsImage;
    public String nodeIcon;
    public String offlineNodeMessage;
    public String openerIconHeight;
    public String openerIconSize;
    public String openerIconWidth;
    public String openerImage;
    public String openIconSuffix;
    public String parentAlreadyContainsChildMessage;
    public String recordDropAppearance;
    public String selectedIconSuffix;
    public String selectionProperty;
    public String separateFolders;
    public String[] serverFilterFields;
    public String showConnectors;
    public String showCustomIconDrop;
    public String showCustomIconOpen;
    public String showCustomIconSelected;
    public String showDisabledSelectionCheckbox;
    public String showDropIcons;
    public String showFolderIcons;
    public String showFullConnectors;
    public String showLoadingIcons;
    public String showNodeIcons;
    public String showOpener;
    public String showOpenIcons;
    public String showPartialSelection;
    public String showRoot;
    public String showSelectedIcons;
    public String showSelectedOpener;
    public String sortFoldersBeforeLeaves;
    public String treeFieldTitle;
    public String treeRootValue;
    public String useAllDataSourceFields;
}

==> smartgwt-13.0p.zip: com/smartgwt/logicalstructure/widgets/tree/TreeGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tree;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TreeGridLogicalStructure extends ListGridLogicalStructure {
    public String alwaysShowOpener;
    public String animateFolderEffect;
    public String animateFolderMaxRows;
    public String animateFolders;
    public String animateFolderSpeed;
    public String animateFolderTime;
    public String autoAssignTreeField;
    public String autoFetchTextMatchStyle;
    public String autoOpenTree;
    public String autoPreserveOpenState;
    public String canAcceptDroppedRecords;
    public String canDragRecordsOut;
    public String canDropOnLeaves;
    public String canDropSiblingAfterLastNode;
    public String canReorderRecords;
    public String canReparentNodes;
    public String canSelectAll;
    public String cantDragIntoChildMessage;
    public String cantDragIntoSelfMessage;
    public String cantDragMultipleNodeOccurencesMessage;
    public String cascadeSelection;
    public String closedIconSuffix;
    public String connectorImage;
    public String createDefaultTreeField;
    public String customIconDropProperty;
    public String customIconOpenProperty;
    public String customIconProperty;
    public String customIconSelectedProperty;
    public String dataArity;
    public String dataFetchMode;
    public Tree dataProperties;
    public DataSource dataSourceAsDataSource;
    public String dataSourceAsString;
    public String displayNodeType;
    public String dropEndSpace;
    public String dropIconSuffix;
    public String extraIconGap;
    public String folderIcon;
    public String folderIconPadding;
    public String groupByFieldAsString;
    public String iconPadding;
    public String iconPaddingProperty;
    public String iconSize;
    public String indentRecordComponents;
    public String indentSize;
    public String initialData;
    public String keepParentsOnFilter;
    public String leaveSelectionCheckboxGap;
    public String loadDataOnDemand;
    public String loadingIcon;
    public String manyItemsImage;
    public String nodeIcon;
    public String offlineNodeMessage;
    public String openerIconHeight;
    public String openerIconSize;
    public String openerIconWidth;
    public String openerImage;
    public String openIconPadding;
    public String openIconSuffix;
    public String parentAlreadyContainsChildMessage;
    public String recordDropAppearance;
    public String saveOpenStateInViewState;
    public String selectedIconSuffix;
    public String selectionProperty;
    public String separateFolders;
    public String[] serverFilterFields;
    public String showConnectors;
    public String showCustomIconDrop;
    public String showCustomIconOpen;
    public String showCustomIconSelected;
    public String showDisabledSelectionCheckbox;
    public String showDropEndSpace;
    public String showDropIcons;
    public String showFolderIcons;
    public String showFullConnectors;
    public String showLoadingIcons;
    public String showNodeIcons;
    public String showOpener;
    public String showOpenIcons;
    public String showPartialSelection;
    public String showRoot;
    public String showSelectedIcons;
    public String showSelectedOpener;
    public String sortFoldersBeforeLeaves;
    public String treeFieldTitle;
    public String treeRootValue;
    public String useAllDataSourceFields;
}
